@@ -216,10 +216,10 @@ Vagrant.configure('2') do |config|
     # Box definition
     ##
     c.vm.box = "{{ instance.box }}"
-    {{ 'c.vm.box_version = "{}"'.format(instance.box_version) if instance.box_version }}
-    {{ 'c.vm.box_url = "{}"'.format(instance.box_url) if instance.box_url }}
-    {{ 'c.vm.box_download_checksum = "{}"'.format(instance.box_download_checksum) if instance.box_download_checksum }}
-    {{ 'c.vm.box_download_checksum_type = "{}"'.format(instance.box_download_checksum_type) if instance.box_download_checksum_type }}
+    {{ 'c.vm.box_version = "{}"'.format(instance.box_version) | safe if instance.box_version }}
+    {{ 'c.vm.box_url = "{}"'.format(instance.box_url) | safe if instance.box_url }}
+    {{ 'c.vm.box_download_checksum = "{}"'.format(instance.box_download_checksum) | safe if instance.box_download_checksum }}
+    {{ 'c.vm.box_download_checksum_type = "{}"'.format(instance.box_download_checksum_type) | safe if instance.box_download_checksum_type }}
 
     ##
     # Config options
@@ -261,6 +261,9 @@ Vagrant.configure('2') do |config|
       {% if instance.provider == "vsphere" %}
       {{ instance.provider | lower }}.memory_mb = {{ instance.memory }}
       {{ instance.provider | lower }}.cpu_count = {{ instance.cpus }}
+      {% elif instance.provider == 'vmware_esxi' %}
+      {{ instance.provider | lower }}.guest_memsize = {{ instance.memory }}
+      {{ instance.provider | lower }}.guest_numvcpus = {{ instance.cpus }}
       {% elif instance.provider.startswith('vmware_') %}
       {{ instance.provider | lower }}.vmx['memsize'] = {{ instance.memory }}
       {{ instance.provider | lower }}.vmx['numvcpus'] = {{ instance.cpus }}
@@ -468,9 +471,7 @@ class VagrantClient:
                 results=self._conf(),
             )
 
-        msg = "Failed to start the VM(s): See log file '{}'".format(
-            self._get_stderr_log(),
-        )
+        msg = f"Failed to start the VM(s): See log file '{self._get_stderr_log()}'"
         with open(self._get_stderr_log(), encoding="utf-8") as f:
             self.result["stderr"] = f.read()
         self._module.fail_json(msg=msg, **self.result)
@@ -674,9 +675,10 @@ class VagrantClient:
         return d
 
     def _get_vagrant_config_dict(self):
-        config_list = []
-        for instance in self.instances:
-            config_list.append(self._get_instance_vagrant_config_dict(instance))
+        config_list = [
+            self._get_instance_vagrant_config_dict(instance)
+            for instance in self.instances
+        ]
         return config_list
 
     def _get_stdout_log(self):
